[![Build Status](https://travis-ci.org/barsgroup/m3-core.svg?branch=3.x)](https://travis-ci.org/barsgroup/m3-core)
## M3-Core

Ядро платформы **M3**

**[Документация](http://m3-core.readthedocs.io/ru/latest/)**

M3 представляет собой набор модулей для разработки web-приложений на python, функционирующих в частных и открытых облаках. Создаваемые на основе M3 приложения функционируют в трехзвенном режиме: web-браузер в качестве тонкого клиента, сервер приложений и сервер баз данных. Рабочие места и сервера, на которых развертываются такие приложения, могут функционировать под любой распространенной операционной системой (Windows, Linux, MacOS). В качестве серверов баз данных могут использоваться различные СУБД: Oracle, PostgeSQL, MS SQL, MySQL, Firebird. На клиентских рабочих местах могут использоваться любые браузеры (кроме IE 6, поддержка которого ограничена).
Ключевыми особенностями платформы являются:
- Ориентированность на создание облачных систем, функционирующих в гетерогенной среде;
- Широкие возможности модификации функциональности и поведения web-приложений без изменения исходного кода системы путем подключения плагинов, которые могут разрабатываться специалистами сторонних компаний;
- Развитый функционал обмена информацией с внешними информационными системами, с использованием REST и SOAP сервисов;
- Многочисленные плагины, в которых реализованы различные полезные механизмы;
- Масштабируемость серверной части как по серверам приложений, так и по серверам базы данных с различными способами балансировки нагрузки.
